@@ -1,32 +1,107 @@
 #include "common.h"
 
-#define NODE(i) CHAR(STRING_ELT(nodes, i))
-#define AMAT(i,j) INTEGER(amat)[i + j * nrows]
-
 #define BLANKET		 1
 #define NEIGHBOUR	 2
 #define PARENT		 3
 #define CHILD		 4
 
-SEXP cache_node_structure(int cur, SEXP nodes, SEXP amat, int nrows,
-    int *status, SEXP debug) {
+static SEXP cache_node_structure(int cur, SEXP nodes, int *amat, int nrows,
+    int *status, int debuglevel);
 
-  int i = 0, j = 0;
-  SEXP structure, names;
-  SEXP mb, nbr, children, parents;
-  int num_parents = 0, num_children = 0, num_neighbours = 0, num_blanket = 0;
+/* compute the cached values fro all nodes. */
+SEXP cache_structure(SEXP nodes, SEXP amat, SEXP debug) {
+
+int i = 0, debuglevel = LOGICAL(debug)[0], length_nodes = LENGTH(nodes);
+int *status = NULL, *a = INTEGER(amat);
+
+  SEXP bn, temp;
+
+  /* allocate the list and set its attributes.*/
+  PROTECT(bn = allocVector(VECSXP, length_nodes));
+  setAttrib(bn, R_NamesSymbol, nodes);
+
+  /* allocate and intialize the status vector. */
+  status = alloc1dcont(length_nodes);
 
   if (isTRUE(debug))
+    Rprintf("* (re)building cached information about network structure.\n");
+
+  /* populate the list with nodes' data. */
+  for (i = 0; i < length_nodes; i++) {
+
+    /* (re)initialize the status vector. */
+    memset(status, '\0', sizeof(int) * length_nodes);
+
+    temp = cache_node_structure(i, nodes, a, length_nodes, status, debuglevel);
+
+    /* save the returned list. */
+    SET_VECTOR_ELT(bn, i, temp);
+
+  }/*FOR*/
+
+  UNPROTECT(1);
+
+  return bn;
+
+}/*CACHE_STRUCTURE*/
+
+/* compute the cached values for a single node (R-friendly). */
+SEXP cache_partial_structure(SEXP nodes, SEXP target, SEXP amat, SEXP debug) {
+
+int i = 0, debuglevel = LOGICAL(debug)[0], length_nodes = LENGTH(nodes);
+char *t = (char *)CHAR(STRING_ELT(target, 0));
+int *status = NULL, *a = INTEGER(amat);
+
+  if (isTRUE(debug))
+    Rprintf("* (re)building cached information about node %s.\n", t);
+
+  /* allocate and initialize the status vector. */
+  status = alloc1dcont(length_nodes);
+
+  /* iterate fo find the node position in the array.  */
+  for (i = 0; i < length_nodes; i++)
+    if (!strcmp(t, CHAR(STRING_ELT(nodes, i))))
+      break;
+
+  /* return the corresponding part of the bn structure. */
+  return cache_node_structure(i, nodes, a, length_nodes, status, debuglevel);
+
+}/*CACHE_PARTIAL_STRUCTURE*/
+
+/* compute the cached values for a single node (C-friendly). */
+SEXP c_cache_partial_structure(int target, SEXP nodes, SEXP amat, int *status, SEXP debug) {
+
+int debuglevel = LOGICAL(debug)[0], length_nodes = LENGTH(nodes);
+int *a = INTEGER(amat);
+
+  /* allocate and initialize the status vector. */
+  if (!(*status))
+    status = alloc1dcont(length_nodes);
+
+  /* return the corresponding part of the bn structure. */
+  return cache_node_structure(target, nodes, a, length_nodes, status, debuglevel);
+
+}/*C_CACHE_PARTIAL_STRUCTURE*/
+
+/* backend to compute the cached values fro a single node. */
+static SEXP cache_node_structure(int cur, SEXP nodes, int *amat, int nrows,
+    int *status, int debuglevel) {
+
+int i = 0, j = 0;
+int num_parents = 0, num_children = 0, num_neighbours = 0, num_blanket = 0;
+SEXP structure, names, mb, nbr, children, parents;
+
+  if (debuglevel > 0)
     Rprintf("* node %s.\n", NODE(cur));
 
   for (i = 0; i < nrows; i++) {
 
-    if (AMAT(cur, i) == 1) {
+    if (amat[CMC(cur, i, nrows)] == 1) {
 
-      if (AMAT(i, cur) == 0) {
+      if (amat[CMC(i, cur, nrows)] == 0) {
 
         /* if a[i,j] = 1 and a[j,i] = 0, then i -> j. */
-        if (isTRUE(debug))
+        if (debuglevel > 0)
           Rprintf("  > found child %s.\n", NODE(i));
 
         status[i] = CHILD;
@@ -34,27 +109,28 @@ SEXP cache_node_structure(int cur, SEXP nodes, SEXP amat, int nrows,
         /* check whether this child has any other parent. */
         for (j = 0; j < nrows; j++) {
 
-          if ((AMAT(j,i) == 1) && (AMAT(i,j) == 0) && (j != cur)) {
+          if ((amat[CMC(j, i, nrows)] == 1) && (amat[CMC(i, j, nrows)] == 0)
+                && (j != cur)) {
 
             /* don't mark a neighbour as in the markov blanket. */
             if (status[j] <= 1) {
 
               status[j] = BLANKET;
 
-              if (isTRUE(debug))
+              if (debuglevel > 0)
                 Rprintf("  > found node %s in markov blanket.\n", NODE(j));
 
             }/*THEN*/
 
           }/*THEN*/
 
-        }/*FOR*/   
+        }/*FOR*/
 
       }/*THEN*/
       else {
 
         /* if a[i,j] = 1 and a[j,i] = 1, then i -- j. */
-        if (isTRUE(debug))
+        if (debuglevel > 0)
           Rprintf("  > found neighbour %s.\n", NODE(i));
 
         status[i] = NEIGHBOUR;
@@ -64,10 +140,10 @@ SEXP cache_node_structure(int cur, SEXP nodes, SEXP amat, int nrows,
     }/*THEN*/
     else {
 
-      if (AMAT(i, cur) == 1) {
+      if (amat[CMC(i, cur, nrows)] == 1) {
 
         /* if a[i,j] = 0 and a[j,i] = 1, then i <- j. */
-        if (isTRUE(debug))
+        if (debuglevel > 0)
           Rprintf("  > found parent %s.\n", NODE(i));
 
         status[i] = PARENT;
@@ -111,7 +187,7 @@ SEXP cache_node_structure(int cur, SEXP nodes, SEXP amat, int nrows,
 
   }/*FOR*/
 
-  if (isTRUE(debug))
+  if (debuglevel > 0)
     Rprintf("  > node %s has %d parent(s), %d child(ren), %d neighbour(s) and %d nodes in the markov blanket.\n",
       NODE(cur), num_parents, num_children, num_neighbours, num_blanket);
 
@@ -174,63 +250,3 @@ SEXP cache_node_structure(int cur, SEXP nodes, SEXP amat, int nrows,
 
 }/*CACHE_NODE_STRUCTURE*/
 
-SEXP cache_structure(SEXP nodes, SEXP amat, SEXP debug) {
-
-  int i = 0;
-  int length_nodes = LENGTH(nodes);
-  int *status;
-
-  SEXP bn, temp;
-
-  /* allocate the list and set its attributes.*/
-  PROTECT(bn = allocVector(VECSXP, length_nodes));
-  setAttrib(bn, R_NamesSymbol, nodes);
-
-  /* allocate and intialize the status vector. */
-  status = alloc1dcont(length_nodes);
-
-  if (isTRUE(debug))
-    Rprintf("* (re)building cached information about network structure.\n");
-
-  /* populate the list with nodes' data. */
-  for (i = 0; i < length_nodes; i++) {
-
-    /* (re)initialize the status vector. */
-    memset(status, '\0', sizeof(int) * length_nodes);
-
-    temp = cache_node_structure(i, nodes, amat, length_nodes, status, debug);
-
-    /* save the returned list. */
-    SET_VECTOR_ELT(bn, i, temp);
-
-  }/*FOR*/
-
-  UNPROTECT(1);
-
-  return bn;
-
-}/*CACHE_STRUCTURE*/
-
-SEXP cache_partial_structure(SEXP nodes, SEXP target, SEXP amat, SEXP debug) {
-
-  int i = 0;
-  int length_nodes = LENGTH(nodes);
-  char *t = (char *)CHAR(STRING_ELT(target, 0));
-  int *status;
-
-  if (isTRUE(debug))
-    Rprintf("* (re)building cached information about node %s.\n", t);
-
-  /* allocate and initialize the status vector. */
-  status = alloc1dcont(length_nodes);
-
-  /* iterate fo find the node position in the array.  */
-  for (i = 0; i < length_nodes; i++)
-    if (!strcmp(t, CHAR(STRING_ELT(nodes, i))))
-      break;
-
-  /* return the corresponding part of the bn structure. */
-  return cache_node_structure(i, nodes, amat, length_nodes, status, debug);
-
-}/*CACHE_PARTIAL_STRUCTURE*/
-
